@@ -112,7 +112,7 @@ gda_column_class_init (GdaColumnClass *klass)
 			      NULL, NULL,
 			      gda_marshal_VOID__INT_INT,
 			      G_TYPE_NONE,
-			      2, G_TYPE_GTYPE, G_TYPE_GTYPE);
+			      2, G_TYPE_INT, G_TYPE_INT);
 
 	/* properties */
         object_class->set_property = gda_column_set_property;
@@ -161,6 +161,13 @@ gda_column_finalize (GObject *object)
 		if (column->priv->default_value) 
 			gda_value_free (column->priv->default_value);
 	
+		g_free (column->priv->table);
+		g_free (column->priv->id);
+		g_free (column->priv->name);
+		g_free (column->priv->title);
+		g_free (column->priv->caption);
+		g_free (column->priv->references);
+
 		g_free (column->priv);
 		column->priv = NULL;
 	}
